# -*- coding: utf-8 -*-
import requests
import json
import tempfile

from odoo import api, models
from odoo.addons.saas_worker.util import wrap_module

requests_api = wrap_module(requests.api, {'delete', 'get', 'head', 'options', 'patch', 'post', 'put', 'request', 'exceptions', 'HTTPError', 'ConnectionError'})
json_api = wrap_module(json, {'dump', 'dumps', 'load', 'loads'})

def mktempfile(prefix='tmp', suffix='', mode='w+b'):
    """ Useful for cases where you either need a temporary file to store big data
        while processing it within a server action, or simply a file with a visible
        FS path.
        One example is the cert_file/key_file parameters passed to `requests` methods
        in order to use client certificates.
    """
    # prevent passing 'dir'
    tmpf = tempfile.NamedTemporaryFile(
        prefix=prefix, suffix=suffix, mode=mode, dir=None, delete=True)
    return tmpf

class IrActionsServer(models.Model):
    _inherit = 'ir.actions.server'

    @api.model
    def _get_eval_context(self, action=None):
        eval_context = super(IrActionsServer, self)._get_eval_context(action=action)
        eval_context.update(requests=requests_api, json=json_api, _mktmpf=mktempfile)
        return eval_context
